#! /bin/sh
#------------------------------------------------------------------
#Procedure to detect autoreply request and generate
#sieve filter used by dovecot application.
#------------------------------------------------------------------
#setting up default env variable.
. `dirname $0`/../shell/version.sh
. $BASE/etc/sysconfig/$APPNAME

#setting the Variable
#first the Data-base type
if [ -z "$DB_TYPE" ] ; then
  DB_TYPE=POSTGRESQL;
  fi

#Then the data-base name
if [ -z "$DB_NAME" ] ; then
  DB_NAME=$APPNAME;
  fi

case "$DB_TYPE" in
  "POSTGRESQL"  )
     if [ ! -z "$DB_PORT" ] ; then
       SQLPORT="-p $DB_PORT"
       fi
     if [ ! -z "$DB_HOST" ] ; then
       SQLHOST="-h $DB_HOST"
       fi
     ;;
  "MYSQL"       )
     if [ ! -z "$DB_PORT" ] ; then
       SQLPORT="-P $DB_PORT"
       fi
     if [ ! -z "$DB_HOST" ] ; then
       SQLHOST="-h $DB_HOST"
       fi
     ;;
  esac
#----------------------------------------------
#procedure to probe data-base qith an SQL request
#as $1 parametere
prob_db()

{
case "$DB_TYPE" in
  "POSTGRESQL"  )
     echo "$1" | psql -t -q  -A -F ' ' $SQLPORT $SQLHOST $DB_NAME
     ;;
  "MYSQL"       )
     echo "$1" | mysql -s -u $APPNAME $SQLPORT $SQLHOST $DB_NAME
     ;;
  esac
}
#------------------------------------------------------------------
clean ()
{
prob_db "SELECT email FROM autoreply WHERE stop<NOW()"	|	\
	while read -r EMAIL
          do
          domain=`echo $EMAIL | cut -d "@" -f 2`
          user=`echo $EMAIL | cut -d "@" -f 1`
     case "$DB_TYPE" in
      "POSTGRESQL"  )
	  user=`echo $user | sed -e "s/'/''/" `
		  ;;
      "MYSQL"       )
	  user=`echo $user | sed -e 's/'\''/\\\\'\''/'`
     ;;
     esac

	  rm -fr $BASE/var/spool/$APPNAME-$VERS/mails/$domain/$user/.dovecot.sieve
	  rm -fr $BASE/var/spool/$APPNAME-$VERS/mails/$domain/$user/.dovecot.lda-dupes
	  done
}
#------------------------------------------------------------------
createHeader ()
#Standard header for all emails

{
echo "require [\"vacation\"];"
}
#------------------------------------------------------------------
createLink()

{
symbolic=$BASE/var/spool/$APPNAME-$VERS/mails/$1/$2/.dovecot.sieve
if [ ! -L $symbolic ]; then
  ln -snf $BASE/var/spool/$APPNAME-$VERS/mails/$domain/$user/sieve/autoreply.sieve $symbolic
  fi
}

#------------------------------------------------------------------
createReply ()
{
#in case the user never ever receiveid an email yet
#we create the dovecot directory 

prob_db "SELECT DISTINCT email FROM autoreply 			\
	  	WHERE start<NOW() AND stop>NOW() AND 		\
	  	new_status=1 AND nomessage=0"		|	\
	(
	while read -r EMAIL
       	  do
	  domain=`echo $EMAIL | cut -d "@" -f 2`
	  user=`echo $EMAIL | cut -d "@" -f 1`
	  direc="$BASE/var/spool/$APPNAME-$VERS/mails/$domain/$user/sieve"
	  if [ ! -d $direc ]; then
	    mkdir -p $direc
	    fi
     case "$DB_TYPE" in
      "POSTGRESQL"  )
	  EMAIL=`echo $EMAIL | sed -e "s/'/''/" `
		  ;;
      "MYSQL"       )
	  EMAIL=`echo $EMAIL | sed -e 's/'\''/\\\\'\''/'`
     ;;
     esac


	  ALIASNOSUB=`prob_db "SELECT alias FROM autoreply 	\
		WHERE email='$EMAIL' AND 			\
		(subject IS NULL OR subject='') AND		\
		(alias IS NOT NULL OR alias<>'') AND		\
		nomessage=0;"`
	  ALIASSUB=`prob_db "SELECT alias FROM autoreply	\
		WHERE email='$EMAIL' AND			\
		(subject IS NOT NULL OR subject<>'') AND	\
		(alias IS NOT NULL OR alias<>'') AND		\
		nomessage=0;"`
	  COUNTERSUB=1
	  COUNTERNOSUB=1
	  (
	  createHeader		

	  #For alias who has a separate subject
	  for alias in $ALIASSUB
	    do
            SUBJECTALIAS=`prob_db "SELECT subject FROM autoreply\
				WHERE email='$EMAIL' AND	\
				alias='$alias';"`
	    MESSAGEALIAS=`prob_db "SELECT message FROM autoreply\
				WHERE email='$EMAIL' AND	\
				alias='$alias';"`
	    if [ $COUNTERSUB -eq 1 ] ; then 
	      echo -n "if header :contains" 
	      fi
	   echo "[\"To\", \"Cc\", \"Bcc\"] \"$alias\"
{
vacation :days 31 :subject \"$SUBJECTALIAS\" 
:addresses [\"$alias\"]
\"$MESSAGEALIAS\";
stop;
}"
	    done
#For the main email vacation + linked alias
	  SUBJECTMAIN=`prob_db "SELECT subject FROM autoreply	\
				WHERE email='$EMAIL' AND	\
				(alias='' OR alias IS NULL);"`
	  MESSAGEMAIN=`prob_db "SELECT message FROM autoreply	\
				WHERE email='$EMAIL' AND	\
				(alias='' OR alias IS NULL);"`

	  if [ $COUNTERSUB -ge 1 ] ; then
	    if [ -n "$ALIASSUB" ] ; then
	      echo "else {"
	    fi
          else
    	    echo "if {"
	  fi
	  echo -n "vacation :days 31 :subject \"$SUBJECTMAIN\""
	  echo ""
	  if [ -n "$ALIASNOSUB" ] ; then
	    NUMNOSUB=`prob_db 					\
			"SELECT COUNT(alias) FROM autoreply 	\
				WHERE email='$EMAIL' AND	\
				(subject='' OR subject IS NULL)	\
				AND nomessage=0;"`
	    echo -n ":addresses ["
	    for alias in $ALIASNOSUB
	      do
	      echo -n "\"$alias\""
	      if [ $COUNTERNOSUB -lt $NUMNOSUB ] ; then
		echo -n ", "
	      else
		echo  "]"
	      fi
	      let COUNTERNOSUB+=1
	      done
	  fi
#	  echo "\"$MESSAGEMAIN\";"
	  echo "text:"
	  echo "$MESSAGEMAIN"
	  echo "."
	  echo ";"
	  if [ -n "$ALIASSUB" ] ; then
	    echo "}"			
	  fi;
	  ) > $BASE/var/spool/$APPNAME-$VERS/mails/$domain/$user/sieve/autoreply.sieve
	  createLink $domain $user
	  prob_db "UPDATE autoreply SET new_status='0' WHERE email='$EMAIL';"
	  done
	)
}

clean
createReply
