#! /bin/sh
#---------------------------------------------------------
#Procedure to create graphic build from collected statistic
#this shell scan all STADIR contents and create graphic 
#picture accordingly.
#$1 time period
#	daily
#	weekly
#	monthly
#	yearly
#----------------------------------------------------------
#local Variable
#----------------------------------------------------------
#extracting the WORKING base
. `dirname $0`/version.sh
#----------------------------------------------------------
STADIR=$BASE/var/lib/$APPNAME-$VERS/stats
GRADIR=$BASE/var/www/$APPNAME-$VERS/graph
#---------------------------------------------------------
#========================================================
#function definition
#---------------------------------------------------------
#makegraf, create a sample from graphic
#$1 contract
#$2 domain
#$3 rate
#$4 range
#$5 unit
makegraph() {
   if [ -f $STADIR/$1/$3/$2 ] ; then
     mkdir -p $GRADIR/$1 ;
     /usr/bin/rrdtool graph $GRADIR/$1/$2.$3.$4.rejected.gif	\
        -e "now" -s "now-1$5"					\
        --title="'rejected' E-mail statistic"			\
        -v "eMPH"						\
        DEF:rejected=$STADIR/$1/$3/$2:rejected:AVERAGE		\
        LINE1:rejected#EA330F:"Rejected Spam Email"

     /usr/bin/rrdtool graph $GRADIR/$1/$2.$3.$4.direct.gif	\
        -e "now" -s "now-1$5"					\
        --title="'Accepted' E-mail statistic"			\
        -v "eMPH"						\
	DEF:direct=$STADIR/$1/$3/$2:direct:AVERAGE		\
	LINE1:direct#0E0EE4:"Accepted E-mail"

     /usr/bin/rrdtool graph $GRADIR/$1/$2.$3.$4.sent.gif	\
        -e "now" -s "now-1$5"					\
        --title="'sent' E-mail statistic"			\
        -v "eMPH"						\
	DEF:relayed=$STADIR/$1/$3/$2:relayed:AVERAGE		\
	LINE1:relayed#06FF6E:"Sent E-mail"

     /usr/bin/rrdtool graph $GRADIR/$1/$2.$3.$4.quarantine.gif	\
        -e "now" -s "now-1$5"					\
        --title="'quarantine' E-mail statistic"			\
        -v "eMPH"						\
	DEF:quarantine=$STADIR/$1/$3/$2:quarantine:AVERAGE	\
	LINE1:quarantine#FFBD06:"in quarantine"

     /usr/bin/rrdtool graph $GRADIR/$1/$2.$3.$4.virus.gif	\
        -e "now" -s "now-1$5"					\
        --title="'virus' E-mail statistic"			\
        -v "eMPH"						\
	DEF:virus=$STADIR/$1/$3/$2:virus:AVERAGE		\
	LINE1:virus#DF06D4:"found virus"

     /usr/bin/rrdtool graph $GRADIR/$1/$2.$3.$4.empty.gif	\
        -e "now" -s "now-1$5"					\
        --title="'no data' E-mail statistic"			\
        -v "eMPH"						\
	DEF:empty=$STADIR/$1/$3/$2:empty:AVERAGE		\
	LINE1:empty#FF0F07:"E-mail empty (no data)"

     /usr/bin/rrdtool graph $GRADIR/$1/$2.$3.$4.vreceived.gif	\
        -e "now" -s "now-1$5"					\
	--title="'Recieved Email volume'"			\
        -v "Bytes"						\
	DEF:vol_in=$STADIR/$1/$3/$2:vol_in:AVERAGE		\
	LINE1:vol_in#0E6AE4:"Received E-mail Volume"

     /usr/bin/rrdtool graph $GRADIR/$1/$2.$3.$4.vsent.gif	\
        -e "now" -s "now-1$5"					\
	--title="'Sent Email volume'"				\
        -v "Bytes"						\
	DEF:vol_out=$STADIR/$1/$3/$2:vol_out:AVERAGE		\
	LINE1:vol_out#06FF0C:"Sent E-mail Volume"

   fi
}
#========================================================
#main loop
#---------------------------------------------------------
(
cd $STADIR
for contract in `ls` 
  do
    if [ -d $contract ] ; then
      (
      for timing in hourly 
	do
        cd $contract/$timing
        for file in `ls` 
	  do
	  case "$1" in 
	    "daily"	)
	      unit="d"; 
	      ;;
	    "weekly"	)
	      unit="w"; 
	      ;;
	    "monthly"	)
	      unit="m"; 
	      ;;
	    "yearly"	)
	      unit="y"; 
	      ;;
	    ""	| "*"	)
	      unit="";
	      echo "$0, unknown \"1\" units!"
	      ;;
	    esac
	  if [ ! -z $unit ] ; then
            makegraph $contract $file $timing $1 $unit 
	   fi
          done
	done
      )
    else
      echo "Warning from $0, \"$STADIR/$contract\" is not a directory"
    fi
  done
)
exit 0
