#! /bin/sh 
#-----------------------------------------------------------------
#Shell script to add local information to configuration file
#-----------------------------------------------------------------
BASE=$1
. `dirname $0`/../shell/version.sh
.  $BASE/etc/sysconfig/$APPNAME
#-----------------------------------------------------------------
#Updating clement httpd configuration file
export hostipv4=`dig \`uname -n\` A +noall +short`;
export hostipv6=`dig \`uname -n\` AAAA +noall +short`;
if [ -z "$domain" ] ; then
  export domain=`dnsdomainname`
  fi

#to make sure we have at least an hostipv4 reference
if [ -z "$hostipv4" -a -z "$hostipv6" ] ; then
  export hostipv4=`grep \`uname -n\` /etc/hosts | cut  -f1`
  fi
#-----------------------------------------------------------------
add_web()

{
cat >> $BASE/etc/httpd/conf.d/$APPNAME.conf <<!EOT
#$APPNAME START
#Done by the $APPNAME first start

NameVirtualHost $1:80

<VirtualHost $1:80>
        ServerName clement.$domain
        ServerAdmin root@$domain
        DocumentRoot $BASE/var/www/$APPNAME-$VERS
	setenv PATH_INFO  $BASE/etc/$APPNAME-$VERS/$APPNAME.php
        Alias  /base-dir/  $BASE/var/www/$APPNAME-$VERS/ 
        Alias /reg-icons/ $BASE/var/www/$APPNAME-$VERS/reg-icons/
        Alias /base-graph/ $BASE/var/www/$APPNAME-$VERS/graph/
	ScriptAlias /cgi-bin/ $BASE/var/www/$APPNAME-$VERS/
        <Directory $BASE/var/www/$APPNAME-$VERS>
                Options MultiViews FollowSymlinks ExecCGI
                AllowOverride AuthConfig FileInfo Indexes Limit Options
                Order allow,deny
		Allow from all
        </Directory>
        ErrorLog logs/clemerr.log
        TransferLog logs/clemlog.log
</VirtualHost>

<VirtualHost $1:80>
        ServerName web.clement.$domain
        ServerAdmin root@$domain
	DirectoryIndex menclem.php
	DocumentRoot $BASE/var/www/$APPNAME-$VERS/web
        Alias /base-graph/ $BASE/var/www/$APPNAME-$VERS/graph/
        <Directory $BASE/var/www/$APPNAME-$VERS>/web
		Options MultiViews FollowSymlinks
		AllowOverride AuthConfig FileInfo Indexes Limit Options
		Order allow,deny
		Allow from all
	</Directory>
        ErrorLog logs/webmerr.log
        TransferLog logs/weblog-ssl.log
</VirtualHost>

<VirtualHost $1:80>
        ServerName webmail.$domain
        ServerAdmin root@$domain
	DirectoryIndex index.php
	DocumentRoot $BASE/usr/share/squirrelmail
	<Directory $BASE/usr/share/squirrelmail>
		Options MultiViews FollowSymlinks
		AllowOverride AuthConfig FileInfo Indexes Limit Options
		Order allow,deny
		Allow from all
	</Directory>
        ErrorLog logs/webmerr.log
        TransferLog logs/weblog-ssl.log
</VirtualHost>

NameVirtualHost $1:443

<VirtualHost $1:443>
        ServerName clement.$domain
        ServerAdmin root@$domain
        DocumentRoot $BASE/var/www/$APPNAME-$VERS
	setenv PATH_INFO  $BASE/etc/$APPNAME-$VERS/$APPNAME.php
        Alias  /base-dir/  $BASE/var/www/$APPNAME-$VERS/ 
        Alias /reg-icons/ $BASE/var/www/$APPNAME-$VERS/reg-icons/
        Alias /base-graph/ $BASE/var/www/$APPNAME-$VERS/graph/
	ScriptAlias /cgi-bin/ $BASE/var/www/$APPNAME-$VERS/
        <Directory $BASE/var/www/$APPNAME-$VERS>
                Options MultiViews FollowSymlinks ExecCGI
                AllowOverride AuthConfig FileInfo Indexes Limit Options
                Order allow,deny
		Allow from all
        </Directory>
	#----------------------------------------------
	#SSL
	SSLEngine On
	SSLCertificateKeyFile	$BASE/etc/pki/$APPNAME-$VERS/clement.pem
	SSLCertificateFile	$BASE/etc/pki/$APPNAME-$VERS/clement.pem
	SSLCertificateChainFile $BASE/etc/pki/$APPNAME-$VERS/StartComClass2PrimaryIntermediateServerCA
	SSLCACertificateFile	$BASE/etc/pki/$APPNAME-$VERS/startcom.ca.pem
	SSLCipherSuite 		ALL:!ADH:!EXPORT:!SSLv2:RC4+RSA:+HIGH:+MEDIUM:+LOW
	#----------------------------------------------
        ErrorLog logs/clemerr-ssl.log
        TransferLog logs/clemlog-ssl.log
</VirtualHost>

<VirtualHost $1:443>
        ServerName webmail.$domain
        ServerAdmin root@$domain
	DirectoryIndex index.php
	DocumentRoot $BASE/usr/share/squirrelmail
	<Directory $BASE/usr/share/squirrelmail>
		Options MultiViews FollowSymlinks
		AllowOverride AuthConfig FileInfo Indexes Limit Options
		Order allow,deny
		Allow from all
	</Directory>
	#----------------------------------------------
	#SSL
	SSLEngine On
	SSLCertificateKeyFile	$BASE/etc/pki/$APPNAME-$VERS/clement.pem
	SSLCertificateFile	$BASE/etc/pki/$APPNAME-$VERS/clement.pem
	SSLCertificateChainFile $BASE/etc/pki/$APPNAME-$VERS/StartComClass2PrimaryIntermediateServerCA
	SSLCACertificateFile	$BASE/etc/pki/$APPNAME-$VERS/startcom.ca.pem
	SSLCipherSuite 		ALL:!ADH:!EXPORT:!SSLv2:RC4+RSA:+HIGH:+MEDIUM:+LOW
	#----------------------------------------------
        ErrorLog logs/webmerr-ssl.log
        TransferLog logs/weblog-ssl.log
</VirtualHost>

#$APPNAME STOP
!EOT
}

#-----------------------------------------------------------------
#to setup the IPV4 WEB interface
if [ -n "$hostipv4" ] ; then
  add_web $hostipv4
  fi

#-----------------------------------------------------------------
#to setup the IPV6 WEB interface
if [ -n "$hostipv6" ] ; then
  add_web $hostipv6
  fi

#-----------------------------------------------------------------
#Updating clement php configuration file
cat >> $BASE/etc/$APPNAME-$VERS/clement.php <<!EOT
<?php
//----------------------------------------------------------------
//application version
\$clemver="$APPNAME-$VERS";
putenv("clemver=\$clemver");
//original subversion number
\$clemrel="$SUBLEV";
putenv("clemrel=\$clemrel");
//----------------------------------------------------------------
//extracting current username
exec("id -n -u",\$MYID,\$retvalue);
\$dbusr=\$MYID[0];
putenv("dbusr=\$dbusr");
//----------------------------------------------------------------
//data-base typ and name
\$sqltype="$DB_TYPE";
putenv("sqltype=\$sqltype");
\$dbname="$APPNAME";
putenv("dbname=\$dbname");
//----------------------------------------------------------------
//working base (usualy empty)
\$base="$BASE";
putenv("base=\$base");
//----------------------------------------------------------------
//Default working language
\$langbase=1;
putenv("langbase=\$langbase");
//----------------------------------------------------------------
//Default encoding password MD5 SHA512 SHA256 BLOWFISH
\$type_crypt="MD5";
putenv("type_crypt=\$type_crypt");
//----------------------------------------------------------------
?>
!EOT
#-----------------------------------------------------------------
#updating dovecot sql access according data-base type
(
echo "#Added by addconfig.sh for $DB_TYPE dat-base type" 
echo "#"`date`
case "$DB_TYPE" in 
  "POSTGRESQL"	)
    echo "driver = pgsql"
    echo "connect=  dbname=$APPNAME"
    ;;
  "MYSQL"	)
    echo "driver = mysql"
    echo "connect= host=localhost dbname=$APPNAME"
    ;;
  esac
) >> $BASE/etc/$APPNAME-$VERS/dovecot-sql.conf
