#! /bin/sh
#------------------------------------------------------------------
#Procedure to convert a mailbox system to clement 2.1 maildir.
#------------------------------------------------------------------
while getopts 'b:d:' OPTION
  do
    case $OPTION in
    b) BASE="$OPTARG"
		;;
    d) domain="$OPTARG"
		;;
    ?) printf "Usage %s: [-b value] [-d value]" $(basename $0) >&2
                exit 2
		;;
    esac
done
#Directory that has the mailbox to maildir and addtomaildir application
mb2mdDIR=`dirname $0`/mb2md
#Directory that is the destination of the transfer.
clemDir=`find $BASE/var/spool/clement* -maxdepth 0 -exec basename {} \;`
clemDir=$BASE/var/spool/$clemDir/mails
#Domain that must be created
if [ -z $domain ] ; then
  domain=`uname -na | cut -f 2- -d "." | cut -d " " -f 1`
fi
#Directory that is the origin of the transfer.
mailboxDir=$BASE/var/spool/mail

#Must be used as root. Otherwise, some privilege will be denied

if [ `id -u` = 0 ] ; then

#Is the specified origin existing?

  if [ -w $mailboxDir ] ; then
#Create the domain folder
    mkdir -p $clemDir/$domain

#Copy paste the aliases from /etc/ to the domain.
    cp $BASE/etc/aliases $clemDir/$domain/.aliases

#strip the path and put users in a list

    all_users=`find $mailboxDir -type f  -exec basename {} \;`
    (for users in $all_users
    do
       if [ -n "`grep -w ^$users $BASE/etc/passwd`" ] ; then
#Conversion to maildir

    $mb2mdDIR $mailboxDir/$users $clemDir/$domain/$users

#Moving content from new to current
if [ `ls -1 $clemDir/$domain/$users/new/ | wc -l` -ge '1' ] ; then
    mv $clemDir/$domain/$users/new/* $clemDir/$domain/$users/cur/
fi
#Yanking their name from etc/passwd and /etc/shadow to .passwd
userpass=`cat $BASE/etc/shadow | grep -w ^$users | cut -f 1,2 -d ":"`
userpass="$userpass:"
userpass="$userpass`cat $BASE/etc/passwd | grep -w ^$users | cut -f 3,4,5 -d ":"`"
userpass="$userpass::"
`echo "$userpass" >> $clemDir/$domain/.passwd`
      fi
    done
)
#Changing permission so clement can read them.
    chown -R clement.mail $clemDir/$domain

  else
    echo "Specified mailbox do not exist. Exiting."
 fi

else
echo "Must be executed as root"
fi


